@@ -62,11 +62,12 @@ describe 'ceph::rgw::keystone' do
 
       it { is_expected.to contain_ceph_config('client.radosgw.gateway/rgw_keystone_url').with_value('http://keystone.default:5000') }
       it { is_expected.to contain_ceph_config('client.radosgw.gateway/rgw_keystone_admin_token').with_value('defaulttoken') }
-      it { is_expected.to contain_ceph_config('client.radosgw.gateway/rgw_keystone_accepted_roles').with_value('_member_, Member') }
+      it { is_expected.to contain_ceph_config('client.radosgw.gateway/rgw_keystone_accepted_roles').with_value('Member') }
       it { is_expected.to contain_ceph_config('client.radosgw.gateway/rgw_keystone_token_cache_size').with_value(500) }
       it { is_expected.to contain_ceph_config('client.radosgw.gateway/rgw_s3_auth_use_keystone').with_value(true) }
       it { is_expected.to contain_ceph_config('client.radosgw.gateway/rgw_keystone_revocation_interval').with_value(600) }
       it { is_expected.to contain_ceph_config('client.radosgw.gateway/nss_db_path').with_value('/var/lib/ceph/nss') }
+      it { is_expected.to contain_ceph_config('client.radosgw.gateway/rgw_keystone_implicit_tenants').with_value(true) }
 
       it { is_expected.to contain_exec('radosgw.gateway-nssdb-ca').with(
          'command' => "/bin/true  # comment to satisfy puppet syntax requirements
@@ -111,8 +112,9 @@ wget --no-check-certificate http://keystone.default:5000/v2.0/certificates/signi
           :rgw_keystone_token_cache_size    => 100,
           :rgw_s3_auth_use_keystone         => false,
           :use_pki                          => false,
-          :rgw_keystone_revocation_interval => 200,
+          :rgw_keystone_revocation_interval => 0,
           :nss_db_path                      => '/some/path/to/nss',
+          :rgw_keystone_implicit_tenants    => false,
         }
       end
 
@@ -121,8 +123,9 @@ wget --no-check-certificate http://keystone.default:5000/v2.0/certificates/signi
       it { is_expected.to contain_ceph_config('client.radosgw.custom/rgw_keystone_accepted_roles').with_value('_role1_,role2') }
       it { is_expected.to contain_ceph_config('client.radosgw.custom/rgw_keystone_token_cache_size').with_value(100) }
       it { is_expected.to contain_ceph_config('client.radosgw.custom/rgw_s3_auth_use_keystone').with_value(false) }
-      it { is_expected.to contain_ceph_config('client.radosgw.custom/rgw_keystone_revocation_interval').with_ensure('absent') }
+      it { is_expected.to contain_ceph_config('client.radosgw.custom/rgw_keystone_revocation_interval').with_value(0) }
       it { is_expected.to contain_ceph_config('client.radosgw.custom/nss_db_path').with_ensure('absent') }
+      it { is_expected.to contain_ceph_config('client.radosgw.custom/rgw_keystone_implicit_tenants').with_value(false) }
 
       it { is_expected.to_not contain_exec('radosgw.custom-nssdb-ca').with(
          'command' => "/bin/true  # comment to satisfy puppet syntax requirements
@@ -203,10 +206,9 @@ wget --no-check-certificate http://keystone.custom:5000/v2.0/certificates/signin
         "
           include ceph::params
           class { 'ceph': fsid => 'd5252e7d-75bc-4083-85ed-fe51fa83f62b' }
-          class { 'ceph::repo': fastcgi => true, }
           include ceph
           ceph::rgw { 'radosgw.gateway': }
-          ceph::rgw::apache_fastcgi { 'radosgw.gateway': }
+          ceph::rgw::apache_proxy_fcgi { 'radosgw.gateway': }
         "
       end
 
@@ -223,11 +225,12 @@ wget --no-check-certificate http://keystone.custom:5000/v2.0/certificates/signin
 
       it { is_expected.to contain_ceph_config('client.radosgw.gateway/rgw_keystone_url').with_value('http://keystone.default:5000') }
       it { is_expected.to contain_ceph_config('client.radosgw.gateway/rgw_keystone_admin_token').with_value('defaulttoken') }
-      it { is_expected.to contain_ceph_config('client.radosgw.gateway/rgw_keystone_accepted_roles').with_value('_member_, Member') }
+      it { is_expected.to contain_ceph_config('client.radosgw.gateway/rgw_keystone_accepted_roles').with_value('Member') }
       it { is_expected.to contain_ceph_config('client.radosgw.gateway/rgw_keystone_token_cache_size').with_value(500) }
       it { is_expected.to contain_ceph_config('client.radosgw.gateway/rgw_s3_auth_use_keystone').with_value(true) }
       it { is_expected.to contain_ceph_config('client.radosgw.gateway/rgw_keystone_revocation_interval').with_value(600) }
       it { is_expected.to contain_ceph_config('client.radosgw.gateway/nss_db_path').with_value('/var/lib/ceph/nss') }
+      it { is_expected.to contain_ceph_config('client.radosgw.gateway/rgw_keystone_implicit_tenants').with_value(true) }
 
       it { is_expected.to contain_exec('radosgw.gateway-nssdb-ca').with(
          'command' => "/bin/true  # comment to satisfy puppet syntax requirements
@@ -254,9 +257,8 @@ wget --no-check-certificate http://keystone.default:5000/v2.0/certificates/signi
         "
           include ceph::params
           class { 'ceph': fsid => 'd5252e7d-75bc-4083-85ed-fe51fa83f62b' }
-          class { 'ceph::repo': fastcgi => true, }
           ceph::rgw { 'radosgw.custom': }
-          ceph::rgw::apache_fastcgi { 'radosgw.custom': }
+          ceph::rgw::apache_proxy_fcgi { 'radosgw.gateway': }
         "
       end
 
@@ -272,8 +274,9 @@ wget --no-check-certificate http://keystone.default:5000/v2.0/certificates/signi
           :rgw_keystone_token_cache_size    => 100,
           :rgw_s3_auth_use_keystone         => false,
           :use_pki                          => false,
-          :rgw_keystone_revocation_interval => 200,
+          :rgw_keystone_revocation_interval => 0,
           :nss_db_path                      => '/some/path/to/nss',
+          :rgw_keystone_implicit_tenants    => false,
         }
       end
 
@@ -282,8 +285,9 @@ wget --no-check-certificate http://keystone.default:5000/v2.0/certificates/signi
       it { is_expected.to contain_ceph_config('client.radosgw.custom/rgw_keystone_accepted_roles').with_value('_role1_,role2') }
       it { is_expected.to contain_ceph_config('client.radosgw.custom/rgw_keystone_token_cache_size').with_value(100) }
       it { is_expected.to contain_ceph_config('client.radosgw.custom/rgw_s3_auth_use_keystone').with_value(false) }
-      it { is_expected.to contain_ceph_config('client.radosgw.custom/rgw_keystone_revocation_interval').with_ensure('absent') }
+      it { is_expected.to contain_ceph_config('client.radosgw.custom/rgw_keystone_revocation_interval').with_value(0) }
       it { is_expected.to contain_ceph_config('client.radosgw.custom/nss_db_path').with_ensure('absent') }
+      it { is_expected.to contain_ceph_config('client.radosgw.custom/rgw_keystone_implicit_tenants').with_value(false) }
 
       it { is_expected.to_not contain_exec('radosgw.custom-nssdb-ca').with(
          'command' => "/bin/true  # comment to satisfy puppet syntax requirements
@@ -310,10 +314,9 @@ wget --no-check-certificate http://keystone.custom:5000/v2.0/certificates/signin
         "
           include ceph::params
           class { 'ceph': fsid => 'd5252e7d-75bc-4083-85ed-fe51fa83f62b' }
-          class { 'ceph::repo': fastcgi => true, }
           include ceph
           ceph::rgw { 'radosgw.gateway': }
-          ceph::rgw::apache_fastcgi { 'radosgw.gateway': }
+          ceph::rgw::apache_proxy_fcgi { 'radosgw.gateway': }
         "
       end
 
